/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.anweisung.anmeldung;

import java.util.ArrayList;
import java.util.List;

import de.bsvrz.ibv.uda.interpreter.daten.dav.MengenObjekt;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext;

/**
 * die Repräsentation eines Ausdrucks zur Definition eines Eintrags für eine
 * Mengenanmeldung.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class MengenAnmeldungsEintragAusdruck implements AnmeldeAusdruck {

	/**
	 * der Ausdruck zur Beschreibung des anzumeldenen Mengenobjekts.
	 */
	private final Ausdruck ausdruck;

	/**
	 * Konstruktor.
	 *
	 * @param ausdruck
	 *            der Ausdruck zur Beschreibung der anzumeldenden Menge
	 */
	public MengenAnmeldungsEintragAusdruck(final Ausdruck ausdruck) {
		this.ausdruck = ausdruck;
	}

	/**
	 * Die Funktion liefert eine Menge mit den sich aus dem Ausdruck ergebenden
	 * Mengenanmeldungseinträgen zurück.
	 *
	 * @param kontext
	 *            der Kontext, in dem der Ausdruck ausgewertet wird
	 * @return die Mengenanmeldungen, die sich aus dem Ausdruck ergeben
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#interpret(de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext)
	 */
	@Override
	public MengenAnmeldungsEintrag[] interpret(final Kontext kontext) {
		final MengenObjekt menge = (MengenObjekt) ausdruck.interpret(kontext);
		return new MengenAnmeldungsEintrag[] { new MengenAnmeldungsEintrag(menge) };
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#getNachfolger()
	 */
	@Override
	public List<Ausdruck> getNachfolger() {
		final List<Ausdruck> liste = new ArrayList<>();
		liste.add(ausdruck);
		return liste;
	}
}
