/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten;

import de.bsvrz.dav.daf.main.config.ObjectTimeSpecification;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.dav.daf.main.config.SystemObjectType;
import de.bsvrz.ibv.uda.interpreter.UdaInterpreter;
import de.bsvrz.ibv.uda.interpreter.daten.container.Feld;
import de.bsvrz.ibv.uda.interpreter.daten.dav.DavDaten;

/**
 * Repräsentation des globalen Kontextobjektes "konfiguration" zum Zugriff auf
 * die Konfigurationsdaten des Datenverteilers.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class KonfigurationsKontext extends SkriptKontext {

	/**
	 * Konstruktor.<br>
	 *
	 * @param interpreter
	 *            der Interpreter, in dem der Kontext verwendet wird
	 */
	public KonfigurationsKontext(final UdaInterpreter interpreter) {
		super(interpreter);
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.SkriptKontext#getStrukturElement(java.lang.String)
	 */
	@Override
	public Object getStrukturElement(final String name) {
		Object result = null;
		if ("objekte".equals(name)) {
			result = new Feld();
			for (final SystemObject object : getInterpreter().getConnection().getDataModel().getObjects(null, null,
					ObjectTimeSpecification.valid())) {
				((Feld) result).einfuegen(0, DavDaten.erzeugeObjekt(getInterpreter().getConnection(), object));
			}

		} else if ("typen".equals(name)) {
			result = new Feld();
			final SystemObjectType type = getInterpreter().getConnection().getDataModel().getTypeTypeObject();
			for (final Object object : type.getElements()) {
				((Feld) result).einfuegen(0, DavDaten.erzeugeObjekt(getInterpreter().getConnection(), object));
			}
		} else if ("attributgruppen".equals(name)) {
			result = new Feld();
			final SystemObjectType type = getInterpreter().getConnection().getDataModel().getType("typ.attributgruppe");
			for (final Object object : type.getElements()) {
				((Feld) result).einfuegen(0, DavDaten.erzeugeObjekt(getInterpreter().getConnection(), object));
			}
		} else if ("aspekte".equals(name)) {
			result = new Feld();
			final SystemObjectType type = getInterpreter().getConnection().getDataModel().getType("typ.aspekt");
			for (final Object object : type.getElements()) {
				((Feld) result).einfuegen(0, DavDaten.erzeugeObjekt(getInterpreter().getConnection(), object));
			}
		}
		return result;
	}
}
