/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.dav;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Operator;

/**
 * Definiton der Operatoren für die Arbeit mit Datenverteiler-Objekten.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class DavOperatoren {

	/** liest einen Datensatz vom Datenverteiler. */
	public static final Operator DATEN_LESEN = Operator.getOperator("datenLesen");

	/** überträgt einen Datensatz zum Datenverteiler. */
	public static final Operator DATEN_SCHREIBEN = Operator.getOperator("datenSchreiben");

	/** erzeugt einen leeren Datensatz für eine Attributgruppe. */
	public static final Operator DATENSATZ = Operator.getOperator("datensatz");

	/** löscht ein dynamisches Objekt. */
	public static final Operator LOESCHEN = Operator.getOperator("löschen");

	/** fügt ein dynamisches Objekt in eine Menge ein. */
	public static final Operator EINFUEGEN = Operator.getOperator("einfügen");

	/** entfernt ein dynamisches Objekt aus einer Menge. */
	public static final Operator ENTFERNEN = Operator.getOperator("entfernen");

	/** liefert den Typ eines Datenverteiler-Datenobjekts. */
	public static final Operator DATA_TYP = Operator.getOperator("typ");

	/** liefert den Name eines Datenverteiler-Datenobjekts. */
	public static final Operator DATA_NAME = Operator.getOperator("name");

	/** liefert die Einheit eines Datenverteiler-Datenobjekts. */
	public static final Operator DATA_EINHEIT = Operator.getOperator("einheit");

	/** liefert den Wertebereich eines Datenverteiler-Datenobjekts. */
	public static final Operator DATA_WERTEBEREICH = Operator.getOperator("wertebereich");

	/** liefert die Statusliste eine Integer-Attributs. */
	public static final Operator DATA_STATUSLISTE = Operator.getOperator("statusliste");

	/** liefert den Wert eines Datenverteiler-Datenobjekt. */
	public static final Operator DATA_WERT = Operator.getOperator("wert");

	/** liefert die Informationen zu einem Datenverteiler-Datenobjekt. */
	public static final Operator DATA_INFO = Operator.getOperator("info");

	/** die Menge der unterstützten Operatoren. */
	public static final Operator[] OPERATOREN = { DavOperatoren.DATEN_LESEN, DavOperatoren.DATEN_SCHREIBEN,
			DavOperatoren.DATENSATZ, DavOperatoren.LOESCHEN, DavOperatoren.EINFUEGEN, DavOperatoren.ENTFERNEN,
			DavOperatoren.DATA_TYP, DavOperatoren.DATA_NAME, DavOperatoren.DATA_WERT, DavOperatoren.DATA_EINHEIT,
			DavOperatoren.DATA_WERTEBEREICH, DavOperatoren.DATA_STATUSLISTE, DavOperatoren.DATA_INFO };

	/** privater Konstruktor für Utility-Klasse. */
	private DavOperatoren() {
		super();
	}
}
