/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.dav;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.config.IntegerValueRange;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.ObjektZugriffsFehler;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.SymbolUndefiniertFehler;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.UdaFehlerSubtyp;

/**
 * die Repräsentation eines ganzzahligen Wertebereichs (
 * {@link IntegerValueRange}) innerhalb eines Uda-Interpreters.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class IntegerValueRangeObjekt extends KonfigurationsObjekt {

	/**
	 * Konstruktor.<br>
	 *
	 * @param verbindung
	 *            die verwendete Datenverteilerverbindung
	 * @param range
	 *            das Systemobjekt
	 */
	public IntegerValueRangeObjekt(final ClientDavInterface verbindung, final IntegerValueRange range) {
		super(verbindung, range);
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.dav.DavDaten#getObjekt()
	 */
	@Override
	public IntegerValueRange getObjekt() {
		return (IntegerValueRange) super.getObjekt();
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.ausdruck.Struktur#getStrukturElement(java.lang.String)
	 * @see #setStrukturElement(String, Object)
	 */
	@Override
	public Object getStrukturElement(final String name) {

		Object result = null;
		final IntegerValueRange object = getObjekt();

		if ("minimum".equals(name)) {
			result = object.getMinimum();
		} else if ("maximum".equals(name)) {
			result = object.getMaximum();
		} else if ("faktor".equals(name)) {
			result = object.getConversionFactor();
		} else if ("einheit".equals(name)) {
			result = object.getUnit();
		} else {
			result = super.getStrukturElement(name);
		}

		if (result == null) {
			result = new SymbolUndefiniertFehler(UdaFehlerSubtyp.ELEMENT);
		}

		return result;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.ausdruck.Struktur#setStrukturElement(java.lang.String,
	 *      java.lang.Object)
	 * @see #getStrukturElement(String)
	 */
	@Override
	public void setStrukturElement(final String name, final Object daten) {
		throw new ObjektZugriffsFehler(UdaFehlerSubtyp.OBJEKT);
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.dav.DavDaten#toString()
	 */
	@Override
	public String toString() {
		final IntegerValueRange range = getObjekt();

		final StringBuffer buffer = new StringBuffer("{");
		buffer.append(range.getMinimum());
		buffer.append(',');
		buffer.append(range.getMaximum());
		buffer.append(',');
		buffer.append(range.getConversionFactor());
		buffer.append(',');
		buffer.append(range.getUnit());
		buffer.append('}');

		return buffer.toString();
	}

}
