/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.fehler;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Operator;

/**
 * Definition der Operatoren, die die Arbeit mit Fehlerobjekten unterstützen.
 * <br>
 * Folgende Operatoren werden unterstützt:
 * <ol>
 * <li>Konstruktor <b>ArithmetischerFehler</b></li>
 * <li>Konstruktor <b>SymbolUndefiniertFehler</b></li>
 * <li>Konstruktor <b>ObjektZugriffsFehler</b></li>
 * <li>Konstruktor <b>ContainerZugriffsFehler</b></li>
 * <li>Konstruktor <b>ArgumentFehler</b></li>
 * <li>Konstruktor <b>DatenZugriffsFehler</b></li>
 * <li>Konstruktor <b>KonfigurationsFehler</b></li>
 * <li>Konstruktor <b>Fehler</b></li>
 * <li><b>meldungen</b> zum Auslesen der Meldungstexte</li>
 * <li><b>fehler</b> zum Prüfen, ob ein Objekt ein Fehlerobjekt ist</li>
 * </ol>
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class FehlerOperatoren {
	/**
	 * Konstruktor für einen <i>FehlerTyp</i>.
	 */
	public static final Operator FEHLER_TYP_KONSTRUKTOR = Operator.getOperator("FehlerTyp");

	/**
	 * Konstruktor für einen <i>ArithmetischerFehler</i>.
	 */
	public static final Operator ARITHMETISCHER_FEHLER_KONSTRUKTOR = Operator.getOperator("ArithmetischerFehler");

	/**
	 * Konstruktor für einen <i>SymbolUndefiniertFehler</i>.
	 */
	public static final Operator SYMBOLUNDEFINIERT_FEHLER_KONSTRUKTOR = Operator.getOperator("SymbolUndefiniertFehler");

	/**
	 * Konstruktor für einen <i>ObjektZugriffsFehler</i>.
	 */
	public static final Operator OBJEKTZUGRIFFS_FEHLER_KONSTRUKTOR = Operator.getOperator("ObjektZugriffsFehler");

	/**
	 * Konstruktor für einen <i>ContainerZugriffsFehler</i>.
	 */
	public static final Operator CONTAINERZUGRIFFS_FEHLER_KONSTRUKTOR = Operator.getOperator("ContainerZugriffsFehler");

	/**
	 * Konstruktor für einen <i>ArgumentFehler</i>.
	 */
	public static final Operator ARGUMENT_FEHLER_KONSTRUKTOR = Operator.getOperator("ArgumentFehler");

	/**
	 * Konstruktor für einen <i>DatenZugriffsFehler</i>.
	 */
	public static final Operator DATENZUGRIFFS_FEHLER_KONSTRUKTOR = Operator.getOperator("DatenZugriffsFehler");

	/**
	 * Konstruktor für einen <i>KonfigurationsFehler</i>.
	 */
	public static final Operator KONFIGURATIONS_FEHLER_KONSTRUKTOR = Operator.getOperator("KonfigurationsFehler");

	/**
	 * Konstruktor füür einen allgemeinen <i>Fehler</i>.
	 */
	public static final Operator FEHLER_KONSTRUKTOR = Operator.getOperator("Fehler");

	/**
	 * Funktion zum Auslesen der Meldungen eines Fehlers und seiner Vorgänger.
	 */
	public static final Operator MELDUNG = Operator.getOperator("meldung");

	/**
	 * Funktion zum Prüfen, ob es sich bei einem Objekt um ein Fehlerobjekt
	 * handelt.
	 */
	public static final Operator IST_FEHLER = Operator.getOperator("fehler");

	/**
	 * die Liste der unterstützten Operatoren.
	 */
	public static final Operator[] OPERATOREN = { FehlerOperatoren.FEHLER_TYP_KONSTRUKTOR,
			FehlerOperatoren.ARGUMENT_FEHLER_KONSTRUKTOR, FehlerOperatoren.ARITHMETISCHER_FEHLER_KONSTRUKTOR,
			FehlerOperatoren.CONTAINERZUGRIFFS_FEHLER_KONSTRUKTOR, FehlerOperatoren.DATENZUGRIFFS_FEHLER_KONSTRUKTOR,
			FehlerOperatoren.KONFIGURATIONS_FEHLER_KONSTRUKTOR, FehlerOperatoren.OBJEKTZUGRIFFS_FEHLER_KONSTRUKTOR,
			FehlerOperatoren.SYMBOLUNDEFINIERT_FEHLER_KONSTRUKTOR, FehlerOperatoren.FEHLER_KONSTRUKTOR,
			FehlerOperatoren.MELDUNG, FehlerOperatoren.IST_FEHLER };

	/** privater Konstruktor für Utility-Klasse. */
	private FehlerOperatoren() {
		super();
	}
}
