/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.client;

/**
 * Schnittstelle für einen Listener, der für Änderungen an einem UdaModul
 * zuständig ist.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public interface ModulListener {

	/**
	 * der Status des Moduls hat sich geändert.
	 *
	 * @param modul
	 *            das Modul
	 * @param valid
	 *            der Gültigkeitsstatus
	 */
	void neuerModulStatus(ClientModul modul, boolean valid);

	/**
	 * ein neues Skript wurde angelegt.
	 *
	 * @param modul
	 *            das Modul
	 * @param skript
	 *            das neue Skript
	 */
	void skriptAngelegt(ClientModul modul, ClientSkript skript);

	/**
	 * ein Skript wurde entfernt.
	 *
	 * @param modul
	 *            das Modul
	 * @param skript
	 *            das entfernte Skript
	 */
	void skriptEntfernt(ClientModul modul, ClientSkript skript);

	/**
	 * ein neuer Skriptlauf wurde angelegt.
	 *
	 * @param modul
	 *            das Modul
	 * @param lauf
	 *            der neue Skriptlauf
	 */
	void skriptLaufAngelegt(ClientModul modul, ClientSkriptLauf lauf);

	/**
	 * ein Skriptlauf wurde entfernt.
	 *
	 * @param modul
	 *            das Modul
	 * @param lauf
	 *            der entfernte Skriptlauf
	 */
	void skriptLaufEntfernt(ClientModul modul, ClientSkriptLauf lauf);
}
