/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.ausdruck;

import java.util.List;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext;
import de.bsvrz.sys.funclib.bitctrl.interpreter.NichtWert;
import de.bsvrz.sys.funclib.bitctrl.interpreter.SymbolUndefiniertException;

/**
 * Repräsentation einer Variable innerhalb eines Uda-Skripts. Eine Variable
 * stellt einen Namen dar, über den auf Daten innerhalb des aktuellen Kontextes
 * der Ausführung eines Uda-Skriptes zugegriffen werden kann.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class Variable implements de.bsvrz.sys.funclib.bitctrl.interpreter.Variable {

	/**
	 * der Name der Variable.
	 */
	private final String name;

	/**
	 * Konstruktor mit Angabe des Variablennamens.
	 *
	 * @param name
	 *            der Name
	 */
	public Variable(final String name) {
		assert name != null;
		this.name = name;
	}

	/**
	 * wertet den Variablenausdruck aus. Die Auswertung ermittelt aus dem
	 * übergebenen Kontext das Objekt, dem der Name der Variable zugeordnet ist.
	 * Wird innerhalb des Kontextes keine entsprechende Variable mit einem
	 * zugeordneten Datenobjekt gefunden, wird ein Objektzugriffsfehler
	 * geworfen.<br>
	 *
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#interpret(de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext)
	 */
	@Override
	public Object interpret(final Kontext kontext) {
		Object result;

		try {
			result = kontext.get(name);
		} catch (@SuppressWarnings("unused") final SymbolUndefiniertException e) {
			// Variable wird angelegt und mit "undefiniert" initialisiert
			kontext.set(name, NichtWert.NICHTWERT);
			result = NichtWert.NICHTWERT;
		}

		return result;
	}

	/**
	 * liefert den Name der Variable, die der Ausdruck definiert.
	 *
	 * @return den Name
	 */
	@Override
	public String getName() {
		return name;
	}

}
