/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten;

import de.bsvrz.ibv.uda.interpreter.UdaInterpreter;
import de.bsvrz.sys.funclib.bitctrl.interpreter.InterpreterException;
import de.bsvrz.sys.funclib.bitctrl.interpreter.NichtWert;

/**
 * Repräsentation des globalen Kontextes zur Speicherung von Konstanten bei der
 * Ausführung eines Uda-Skripts.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class KonstantSkriptKontext extends SkriptKontext {

	/**
	 * Konstruktor.<br>
	 *
	 * @param interpreter
	 *            der Interpreter, in dem der Kontext verwendet wird
	 *
	 */
	public KonstantSkriptKontext(final UdaInterpreter interpreter) {
		super(interpreter);
		setStrukturElement("pi", Math.PI);
		setStrukturElement("e", Math.E);
		setStrukturElement("GrößteZahl", Double.MAX_VALUE);
		setStrukturElement("GrößteGanzeZahl", Long.MAX_VALUE);
		setStrukturElement("Größte32BitGanzeZahl", Integer.MAX_VALUE);
		setStrukturElement("KleinsteZahl", (-Double.MAX_VALUE));
		setStrukturElement("KleinsteGanzeZahl", Long.MIN_VALUE);
		setStrukturElement("Kleinste32BitGanzeZahl", Integer.MIN_VALUE);
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.SkriptKontext#setStrukturElement(java.lang.String,
	 *      java.lang.Object)
	 */
	@Override
	public final void setStrukturElement(final String name, final Object wert) {
		if (enthaelt(name)) {
			final Object oldValue = get(name);
			if ((oldValue != null) && (oldValue != NichtWert.NICHTWERT)) {
				if (!wert.equals(oldValue)) {
					throw new InterpreterException("Überschreiben der Konstante " + name
							+ " ist nicht erlaubt");
				}
			}
		}

		super.set(name, wert);
	}
}
