/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.dav;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.ibv.uda.interpreter.daten.container.Feld;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.ObjektZugriffsFehler;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.UdaFehlerSubtyp;
import de.bsvrz.sys.funclib.bitctrl.interpreter.logik.LogischerWert;

/**
 * Repräsentation eines Systemobjekts ({@link SystemObject}) innerhalb eines
 * Uda-Interpreters.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class SystemObjectObjekt extends DavDaten {

	/**
	 * Konstruktor.<br>
	 *
	 * @param verbindung
	 *            die verwendete Datenverteilerverbindung
	 * @param objekt
	 *            das zu Grunde liegende Systemobjekt
	 */
	protected SystemObjectObjekt(final ClientDavInterface verbindung, final SystemObject objekt) {
		super(verbindung, objekt);
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.ausdruck.Struktur#getStrukturElement(java.lang.String)
	 * @see #setStrukturElement(String, Object)
	 */
	@Override
	public Object getStrukturElement(final String name) {
		Object result = null;
		final SystemObject object = getObjekt();

		if ("pid".equals(name)) {
			result = object.getPid();
		} else if ("id".equals(name)) {
			result = object.getId();
		} else if ("name".equals(name)) {
			result = object.getNameOrPidOrId();
		} else if ("info".equals(name)) {
			result = DavDaten.erzeugeObjekt(getVerbindung(), object.getInfo());
		} else if ("typ".equals(name)) {
			result = DavDaten.erzeugeObjekt(getVerbindung(), object.getType());
		} else if ("gültig".equals(name)) {
			result = LogischerWert.of(getObjekt().isValid());
		} else if ("dynamisch".equals(name)) {
			result = LogischerWert.of(this instanceof DynamischesObjekt);
		} else if ("attributgruppen".equals(name)) {
			result = new Feld();
			for (final AttributeGroup obj : object.getType().getAttributeGroups()) {
				((Feld) result).einfuegen(0, DavDaten.erzeugeObjekt(getVerbindung(), obj));
			}
		}
		if (result == null) {
			result = new ObjektZugriffsFehler(UdaFehlerSubtyp.ELEMENT, "Der Zugriff auf des Element \"" + name
					+ "\" ist nicht möglich");
		}

		return result;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.dav.DavDaten#getObjekt()
	 */
	@Override
	public SystemObject getObjekt() {
		return (SystemObject) super.getObjekt();
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.ausdruck.Struktur#setStrukturElement(java.lang.String,
	 *      java.lang.Object)
	 * @see #getStrukturElement(String)
	 */
	@Override
	public void setStrukturElement(final String name, final Object daten) {
		throw new ObjektZugriffsFehler(UdaFehlerSubtyp.OBJEKT);
	}
}
