/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.fehler;

/**
 * der Subtyp eines {@link UdaFehler}.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public enum UdaFehlerSubtyp {
	/**
	 * es existiert kein definierter Subtyp.
	 */
	UNBEKANNT, /**
	 * eine falsche Anzahl von Argumenten wurde an eine Funktion
	 * übergeben.
	 */
	ANZAHL, /**
	 * ein unzulässiger Argumenttyp wurde übergeben.
	 */
	ARGUMENTE, /**
	 * der Wertebereich für ein Objekt wurde verletzt.
	 */
	BEREICH, /**
	 * eine unzulässige Division durch 0 konnte nicht ausgeführt
	 * werden.
	 */
	DIVISION, /**
	 * Zahlenüberlauf.
	 */
	OVERFLOW, /**
	 * ungültiger Index bei einem Containerzugriff.
	 */
	INDEX, /**
	 * eine Containerselektion hat kein Ergebnis geliefert.
	 */
	SELEKTION, /**
	 * ungültige Attributgruppe.
	 */
	ATTRIBUTGRUPPE, /**
	 * ungültiger Aspekt.
	 */
	ASPEKT, /**
	 * keine Rechte für den Datenzugriff.
	 */
	RECHTE, /**
	 * keine Quelle für eine Datenspezifikation vorhanden.
	 */
	QUELLE, /**
	 * Quelle hat keine Daten für eine Datenspezifikation geliefert.
	 */
	DATEN, /**
	 * ein Archivzugriff konnte nicht erfolgreich ausgeführt werden.
	 */
	ARCHIV, /**
	 * ein angegebenes Attribut hat keinen definierten Wert.
	 */
	ATTRIBUT_UNDEFINIERT, /**
	 * ein Attribut existiert nicht.
	 */
	ATTRIBUT, /**
	 * es ist keine Senke für eine Datenspezifikation vorhanden.
	 */
	SENKE, /**
	 * ein gesuchtes Systemobjekt existiert nicht.
	 */
	OBJEKT, /**
	 * es wurde versucht eine nichtdynamische Menge zu ändern.
	 */
	MENGE, /**
	 * Methide nicht definiert.
	 */
	METHODE, /**
	 * Element nicht definiert.
	 */
	ELEMENT, /**
	 * Variable nicht definiert.
	 */
	VARIABLE, /**
	 * Funktion nicht definiert.
	 */
	FUNKTION, /**
	 * die angegebene PID für ein neues Objekt existiert bereits.
	 */
	PID;

	/**
	 * {@inheritDoc}.
	 *
	 * @see java.lang.Enum#toString()
	 */
	@Override
	public String toString() {
		switch (this) {
		case ANZAHL:
			return "Falsche Anzahl von Argumenten";
		case ARGUMENTE:
			return "Funktion oder Operator mit den übergebenen Argumenttypen nicht ausführbar";
		case BEREICH:
			return "Argument außerhalb eibes definierten Wertebereichs";
		case DIVISION:
			return "Division durch 0";
		case OVERFLOW:
			return "Overflow";
		case INDEX:
			return "Containerzugriff mit ungültigem Index";
		case SELEKTION:
			return "Containerselektion ohne Ergebnis";
		case ATTRIBUTGRUPPE:
			return "falsche Attributgruppe";
		case ASPEKT:
			return "falscher Aspekt";
		case RECHTE:
			return "keine Rechte";
		case QUELLE:
			return "keine Quell-Applikation angemeldet";
		case DATEN:
			return "Quell-Applikation kann keine Daten liefern";
		case ARCHIV:
			return "Archivzugriff gescheitert";
		case ATTRIBUT_UNDEFINIERT:
			return "Zugriff auf undefinierte Attribute";
		case ATTRIBUT:
			return "Zugriff auf ein nicht vorhandenes Attribut";
		case SENKE:
			return "keine Senke angemeldet";
		case OBJEKT:
			return "Zugriff auf nicht existierende Konfigurationsobjekte";
		case MENGE:
			return "Änderung von nichtdynamischen Mengen versucht";
		case METHODE:
			return "Methode nicht definiert";
		case ELEMENT:
			return "Element nicht definiert";
		case VARIABLE:
			return "Variable nicht definiert";
		case FUNKTION:
			return "Funktion nicht definiert";
		case UNBEKANNT:
		default:
			return "";
		}
	}
}
