/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.struktur;

import java.util.ArrayList;
import java.util.List;

import de.bsvrz.ibv.uda.interpreter.AbstractUdaHandler;
import de.bsvrz.sys.funclib.bitctrl.interpreter.*;

/**
 * Handler für Operationen über nutzerdefinierte Datenstrukturen.<br>
 * Folgende Operatoren werden unterstützt:
 * <ul>
 * <li><b>Datenstruktur</b> - erzeugt eine Datenstruktur-Definition</li>
 * <li><b>datensatz</b> - erzeugt eine Instanz aus einer
 * Datenstruktur-Definition</li>
 * <li><b>datenstruktur</b> - liefert die Datenstruktur-Definition auf dem eine
 * Datenstruktur basiert</li>
 * </ul>
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class DatenStrukturHandler extends AbstractUdaHandler {

	/**
	 * {@inheritDoc}.
	 *
	 * @return die Liste der unterstützten Operatoren
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Handler#getHandledOperators()
	 */
	@Override
	public Operator[] getHandledOperators() {
		return DatenStrukturOperatoren.OPERATOREN;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Handler#validiereHandler(de.bsvrz.sys.funclib.bitctrl.interpreter.Operator,
	 *      java.util.List)
	 */
	@Override
	public HandlerValidation validiereHandler(final Operator operator, final List<?> operanden) {
		boolean anzahlOk = false;
		boolean typOk = false;
		if (DatenStrukturOperatoren.KONSTRUKTOR.equals(operator)) {
			if (operanden.size() > 0) {
				anzahlOk = true;
				typOk = true;
				for (int idx = 0; idx < operanden.size(); idx++) {
					if (!(operanden.get(idx) instanceof String)) {
						typOk = false;
						break;
					}
				}
			}
		} else if (DatenStrukturOperatoren.DATENSATZ.equals(operator)) {
			if (operanden.size() >= 1) {
				anzahlOk = true;
				if (Handler.getOperand(operanden, 0) instanceof DatenStrukturDefinition) {
					final DatenStrukturDefinition definition = (DatenStrukturDefinition) operanden.get(0);
					if (definition.getFields().length >= (operanden.size() - 1)) {
						typOk = true;
					}
				}
			}
		} else if (DatenStrukturOperatoren.DATENSTRUKTUR.equals(operator)) {
			if (operanden.size() == 1) {
				anzahlOk = true;
				if (Handler.getOperand(operanden, 0) instanceof DatenStruktur) {
					typOk = true;
				}
			}
		}
		return new HandlerValidation(anzahlOk, typOk);
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Handler#perform(de.bsvrz.sys.funclib.bitctrl.interpreter.Operator,
	 *      java.util.List)
	 */
	@Override
	public Object perform(final Operator operator, final List<?> operanden) {
		erzeugeHandlerFehler(operator, operanden);

		Object result = null;

		if (DatenStrukturOperatoren.KONSTRUKTOR.equals(operator)) {
			final String[] fields = new String[operanden.size()];
			for (int idx = 0; idx < fields.length; idx++) {
				fields[idx] = (String) operanden.get(idx);
			}
			result = new DatenStrukturDefinition(fields);
		} else if (DatenStrukturOperatoren.DATENSATZ.equals(operator)) {
			final DatenStrukturDefinition definition = (DatenStrukturDefinition) operanden.get(0);
			List<?> datenListe = null;
			if (operanden.size() > 1) {
				datenListe = operanden.subList(1, operanden.size());
			} else {
				datenListe = new ArrayList<>();
			}
			result = new DatenStruktur(definition, datenListe.toArray());
		} else if (DatenStrukturOperatoren.DATENSTRUKTUR.equals(operator)) {
			final DatenStruktur struktur = (DatenStruktur) operanden.get(0);
			result = struktur.getDefinition();
		}
		return result;
	}
}
