/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.uda.data;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import de.bsvrz.sys.funclib.bitctrl.daf.AbstractDavZustand;

/**
 * die Repräsentation des Starttyps für die Ausführung eines Skriptlaufs.<br>
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class StartTyp extends AbstractDavZustand {

	/**
	 * Versions-ID für die Serialisierung des Objekts.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * die Liste aller definierter Typen.
	 */
	private static final Map<Integer, StartTyp> TYPEN = new HashMap<>();

	/**
	 * Skript soll sofort nach Freigabe ausgeführt werden.
	 */
	public static final StartTyp SOFORT = new StartTyp(1, "sofort");

	/**
	 * Skript wird erst auf Anforderung vom Nutzer ausgeführt.
	 */
	public static final StartTyp EXPLIZIT = new StartTyp(2, "explizit");

	/**
	 * das Skript wird zyklisch ausgeführt.
	 */
	public static final StartTyp ZYKLISCH = new StartTyp(3, "zyklisch");

	/**
	 * Konstruktor.<br>
	 * Die Funktion erzeugt ein Typobjekt mit den übergebenen Werten für Code
	 * und Bezeichnung.
	 *
	 * @param code
	 *            der Code
	 * @param name
	 *            die Bezeichnung
	 */
	private StartTyp(final int code, final String name) {
		super(code, name);
		StartTyp.TYPEN.put(code, this);
	}

	/**
	 * liefert den Zustand für den übergebenen Code.
	 *
	 * @param searchedCode
	 *            der Code
	 * @return der Zustand
	 */
	public static StartTyp getZustand(final int searchedCode) {
		return StartTyp.TYPEN.get(searchedCode);
	}

	/**
	 * liefert die Liste aller Typen.
	 *
	 * @return die Liste
	 */
	public static Collection<StartTyp> getElemente() {
		return StartTyp.TYPEN.values();
	}
}
